@@ -1,7 +1,7 @@
 /*
  * ==========================================================================
  *                  NetPerfMeter -- Network Performance Meter
- *                 Copyright (C) 2009-2022 by Thomas Dreibholz
+ *                 Copyright (C) 2009-2024 by Thomas Dreibholz
  * ==========================================================================
  *
  * This program is free software: you can redistribute it and/or modify
@@ -1135,7 +1135,7 @@ uint64_t random64()
 /* ###### Get 32-bit random value ######################################## */
 uint32_t random32()
 {
-#ifdef NDEBUG
+#if defined(SIM_IMPORT) || defined(OMNETPPLIBS_IMPORT)
 #warning Using OMNeT++ random generator instead of time-seeded one!
    const double value = uniform(0.0, (double)0xffffffff);
    return((uint32_t)rint(value));
